
//  Copyright (C) 2009 by Arnaud Dupuis
//  a.dupuis@infinityperl.org
//  http://www.infinityperl.org
// 
//  This program is free software; you can redistribute it and/or modify
//  it under the terms of the GNU General Public License as published by
//  the Free Software Foundation; either version 3 of the License, or
//  (at your option) any later version.
// 
//  This program is distributed in the hope that it will be useful,
//  but WITHOUT ANY WARRANTY; without even the implied warranty of
//  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//  GNU General Public License for more details.
// 
//  You should have received a copy of the GNU General Public License
//  along with this program; if not, write to the
//  Free Software Foundation, Inc.,
//  59 Temple Place - Suite 330, Boston, MA  02111-1307, USA

#include "assuma_searchwidget.h"
#include "assuma_mainwindow.h"

AssumaSearchWidget::AssumaSearchWidget(QWidget *parent, QTreeWidget *tw) : QWidget(parent){
	setupUi(this);
	_treeWidget = tw;
	setFocusProxy(searchQuery);
}

void AssumaSearchWidget::loadTheme( const QString & themeName ){
	if( ! AssumaMW )
		return;
	QIcon icon;
	icon.addFile(AssumaMW->getImageFromTheme(themeName,"button-erase"), QSize(), QIcon::Normal, QIcon::Off);
	clearSearchButton->setIcon(icon);
	QIcon icon1;
	icon1.addFile(AssumaMW->getImageFromTheme(themeName,"search-user"), QSize(), QIcon::Normal, QIcon::Off);
	doSearchButton->setIcon(icon1);
	rightCornerPixmap->setPixmap(QPixmap(AssumaMW->getImageFromTheme(themeName,"search-corner")));
}

QSize AssumaSearchWidget::sizeHint () const{
	return QSize(460,180);
}

void AssumaSearchWidget::setTreeWidget(QTreeWidget *tw){
	_treeWidget = tw;
}

QTreeWidget* AssumaSearchWidget::treeWidget(){
	return _treeWidget;
}

void AssumaSearchWidget::setCornerPixmap(const QPixmap & pix){
	rightCornerPixmap->setPixmap(pix);
}

QPixmap AssumaSearchWidget::cornerPixmap() {
	return rightCornerPixmap->pixmap()->copy();
}

void AssumaSearchWidget::on_liveSearchBox_stateChanged( int state ){
	if( state == Qt::Checked){
		doSearchButton->setEnabled(false);
		on_searchQuery_textChanged( searchQuery->text() );
	}
	else
		doSearchButton->setEnabled(true);
}

void AssumaSearchWidget::on_searchQuery_textChanged(const QString & query){
	if( liveSearchBox->isChecked() && query.length() >= 3 ){
		performSearch(query);
	}
	else if(query == ""){
		QTreeWidgetItem *rootitem = _treeWidget->invisibleRootItem();
		for(int k=0;k<rootitem->childCount(); k++)
		{
			rootitem->child(k)->setHidden(false);
		}
	}
}

void AssumaSearchWidget::performSearch(const QString & query){
	if( _treeWidget ){
		int fn_col, mn_col, ln_col,e_col,pn_col,c_col;
		bool shouldSearch = false;
		if(nameSearchBox->isChecked()){
			fn_col = elementColumn( tr("FirstName") );
			mn_col = elementColumn( tr("MaidenName") );
			ln_col = elementColumn( tr("LastName") );
			shouldSearch=true;
		}
		if( extraSearchBox->isChecked() ){
			e_col = elementColumn( tr("Email") );
			pn_col = elementColumn( tr("PhoneNumber") );
			c_col = elementColumn( tr("Comment") );
			shouldSearch=true;
		}
		Qt::CaseSensitivity caseSensitivity;
		if( caseSensitiveBox->isChecked() )
			caseSensitivity = Qt::CaseSensitive;
		else
			caseSensitivity = Qt::CaseInsensitive;
		if(shouldSearch){
			QTreeWidgetItem *rootitem = _treeWidget->invisibleRootItem();
			for(int k=0;k<rootitem->childCount(); k++)
			{
				QTreeWidgetItem *it = rootitem->child(k);
				if( it->text(fn_col).contains( query, caseSensitivity ) || it->text(mn_col).contains( query, caseSensitivity ) || it->text(ln_col).contains( query, caseSensitivity ) || it->text(e_col).contains( query, caseSensitivity ) || it->text(pn_col).contains( query, caseSensitivity ) || it->text(c_col).contains( query, caseSensitivity ))
					it->setHidden(false);
				else
					it->setHidden(true);
			}
		}
	}
}

void AssumaSearchWidget::setColumnMap(const QMap<QString, int> map){
	columnMap = map;
}

int AssumaSearchWidget::elementColumn(const QString & t){
	if (columnMap.contains(t))
		return columnMap.value( t );
	else
		return -1;
}

void AssumaSearchWidget::on_caseSensitiveBox_stateChanged ( int /*state*/ ){
	on_searchQuery_textChanged( searchQuery->text() );
}

void AssumaSearchWidget::on_extraSearchBox_stateChanged ( int /*state*/ ){
	on_searchQuery_textChanged( searchQuery->text() );
}

void AssumaSearchWidget::on_nameSearchBox_stateChanged ( int /*state*/ ){
	on_searchQuery_textChanged( searchQuery->text() );
}

void AssumaSearchWidget::on_clearSearchButton_clicked(bool){
	searchQuery->setText("");
}

void AssumaSearchWidget::on_doSearchButton_clicked(bool){
	performSearch(searchQuery->text());
}
